@@ -1,9 +1,9 @@
 #!PERL
 
 #	$RCSfile: dbupdate.pl,v $
-#	$Revision: 0.32 $
+#	$Revision: 0.33 $
 #	$Author: david $
-#	$Date: 1995/02/10 11:38:56 $
+#	$Date: 1995/02/24 11:13:22 $
 
 # This is a client that will update objects read from a file directly
 # in the database, without interference of updated.
@@ -31,7 +31,9 @@ require "syslog.pl";
 
 # Parse options:
 #
+#
 # -l logfile		- log output to file in stead of STDOUT
+# -n logtext		- Network update - use logtext in acklog file
 # -v			- verbose output (LONGACK)
 # -M			- treat input file (or STDIN) as mail and compose
 #				and send ack mail back
@@ -41,8 +43,10 @@ require "syslog.pl";
 #                         with nic-handle "assign" and return person entry
 #                         with the handle assigned and filled in.
 #                         (very RIPE database dependent)
+# -F                    - Do fast update without mail and other stuff
+# -S                    - Do only syntax check - Not implemented
 
-&Getopts('l:vMAHV');
+&Getopts('ln:vMAHVFS');
 
 # Need this below for running perl in tainted mode.
 
@@ -106,6 +110,7 @@ sub printstat {
     
     print "[$ATTL{$type}] $entry{$type}\n\n";
     print STDERR "dbupdate - printstat 4\n" if $opt_V;
+ 
 }
 
 
@@ -304,10 +309,10 @@ sub doaction {
 
 		# all was OK, print object if nichandle assign mode
 
-		if ($opt_H) {
-		    &enwrite(*entry,1,1);
+		if ($opt_H || $opt_F) {
+                   print "\n" if &enwrite(*entry,1,1);
 		}
-		
+                
 		&dbunlock(*db);
 		&dbclose(*db);
 		&dbclclose();
@@ -384,12 +389,12 @@ if (!$somethingfound) {
     print "** No objects were found in your message **\n";
 }
 elsif ($haserror) {
-    print "$ACKERR" unless $opt_H;
+    print "$ACKERR" unless ($opt_H || $opt_F);
 } else {
-    print "$ACKOK" unless $opt_H;
+    print "$ACKOK" unless ($opt_H || $opt_F);
 }
 
-print $ACKSIG unless $opt_H;
+print $ACKSIG unless ($opt_H || $opt_F);
 
 close(COPY);
 close(STDOUT);
@@ -447,8 +452,13 @@ if (open(LOG, ">>$realfile")) {
     if ($opt_M) {
 	print LOG "\n>>> MAIL UPDATE <<<\n\n";
     } else {
-	print LOG "\n>>> STDIN UPDATE <<<\n\n";
-    }
+       if ($opt_n) {
+          print LOG "\n>>> $opt_n UPDATE <<<\n\n";
+       }
+       else {
+	  print LOG "\n>>> STDIN UPDATE <<<\n\n";
+       } 
+   }
 
     open(TMP, "$TMPDIR/dbupdcopy.$$");
 
@@ -474,7 +484,12 @@ if (open(LOG, ">>$realfile")) {
     if ($opt_M) {
 	print LOG "\n>>> MAIL ACK <<<\n\n";
     } else {
-	print LOG "\n>>> STDIN ACK <<<\n\n";
+        if ($opt_n) {
+           print LOG "\n>>> $opt_n ACK <<<\n\n";
+        }
+        else {
+	   print LOG "\n>>> STDIN ACK <<<\n\n";
+        }
     }
     open(TMP, "$TMPDIR/dbupdack.$$");
     while (<TMP>) {
